@@ -1,4 +1,5 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -45,6 +46,10 @@
 
 #include <cc++/config.h>
 
+#ifndef CCXX_STRING_H_
+#include <cc++/string.h>
+#endif
+
 #ifndef WIN32
 #define	CCXX_POSIX
 #endif // !WIN32
@@ -182,7 +187,7 @@ class __EXPORT Mutex
 {
 private:
 	static bool _debug;
-	const char *_name;
+	String _name;
 #ifndef WIN32
 #ifndef	PTHREAD_MUTEXTYPE_RECURSIVE
 	int volatile _level;
@@ -785,9 +790,21 @@ public:
 	 */
 	void post(void);
 
+#ifndef WIN32
+  /**
+	 * Call it after a deferred cancellation to avoid deadlocks.
+	 * From PTHREAD_COND_TIMEDWAIT(3P): A condition wait (whether timed or not) 
+	 * is a cancellation point. When the cancelability enable state of a thread 
+	 * is set to PTHREAD_CANCEL_DEFERRED, a side effect of acting upon a 
+	 * cancellation request while in a condition wait is that the mutex is 
+	 * (in effect) re-acquired before calling the first cancellation cleanup handler.
+   */
+  void force_unlock_after_cancellation();
+
+#endif // WIN32
+
 	// FIXME: how implement getValue for posix compatibility ?
 	// not portable...
-
 #if	0
 	/**
 	 * Get the current value of a semaphore.
