@@ -1,4 +1,5 @@
 // Copyright (C) 2004-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -45,11 +46,45 @@
 namespace ost {
 #endif
 
+MapIndex& MapIndex::operator=(MapObject *theObject)
+{
+	thisObject = theObject;
+	return *this;
+}
+
+MapIndex& MapIndex::operator++() 
+{ 
+	if ( thisObject == NULL )
+		return *this;
+
+	if (thisObject->nextObject != NULL)
+  {
+		thisObject = thisObject->nextObject;
+	}
+	else if (thisObject->table != NULL)
+	{
+    MapObject* obj = NULL;
+		unsigned i = thisObject->table->getIndex(thisObject->idObject) + 1;
+
+		
+		thisObject->table->enterMutex();
+		for ( ; obj == NULL && i < thisObject->table->range; i++)
+				obj = thisObject->table->map[i];
+		thisObject->table->leaveMutex();
+
+		thisObject = obj;
+	}
+
+	return *this;
+}
+
 MapTable::MapTable(unsigned size) :
 Mutex()
 {
 	map = new MapObject *[size + 1];
 	memset(map, 0, sizeof(MapObject *) * (size + 1));
+	range = size;
+  count = 0;
 }
 
 MapTable::~MapTable()
@@ -83,16 +118,49 @@ void *MapTable::getObject(const char *id)
 
 	enterMutex();
 	MapObject *obj = map[getIndex(id)];
-	leaveMutex();
 
 	while(obj) {
 		if(!stricmp(obj->idObject, id))
 			break;
 		obj = obj->nextObject;
 	}
+	leaveMutex();
 	return (void *)obj;
 }
 
+void *MapTable::getFirst()
+{
+	MapObject *obj;
+
+	if(!map)
+		return NULL;
+
+	enterMutex();
+	obj = *map;
+	for (register unsigned i = 0; obj == NULL && i < range; i++)
+			obj = map[i];
+	leaveMutex();
+	return obj;
+}
+
+void *MapTable::getLast()
+{
+	MapObject *obj = NULL;
+
+	if(!map)
+		return NULL;
+
+	enterMutex();
+	for (register int i = range - 1; obj == NULL && i >= 0; i--)
+		obj = map[i];
+
+	if ( obj != NULL )
+		while ( obj->nextObject != NULL )
+			obj = obj->nextObject;
+	leaveMutex();
+	return obj;
+}
+
 void *MapTable::getFree(void)
 {
 	enterMutex();
@@ -123,6 +191,8 @@ void MapTable::addObject(MapObject &obj)
 	enterMutex();
 	obj.nextObject = map[idx];
 	map[idx] = &obj;
+  obj.table = this;
+  count++;
 	leaveMutex();
 }
 
@@ -168,6 +238,7 @@ void MapObject::detach(void)
 		table->map[idx] = nextObject;
 	else if(node)
 		prev->nextObject = nextObject;
+  table->count--;
 	table->leaveMutex();
 	table = NULL;
 }
