@@ -2356,8 +2356,8 @@ Socket(fam, SOCK_DCCP, IPPROTO_DCCP)
 #ifdef	CCXX_IPV6
 	struct sockaddr_in6 addr6;
 #endif
-	struct sockaddr *ap;
-	socklen_t = alen = sizeof(addr);
+	struct sockaddr_in *ap;
+  socklen_t alen = 0;
 
 	struct servent *svc;
 
@@ -2410,13 +2410,14 @@ Socket(fam, SOCK_DCCP, IPPROTO_DCCP)
 		alen = sizeof(addr6);
 		break;
 #endif
-	default:
+	case IPV4:
 		IPV4Address ia(name);
 		addr.sin_addr = getaddress(ia);
 		ap = &addr;
+    alen = sizeof(addr);
 	}
 
-	if(bind(so, ap, alen)) {
+	if(bind(so, (struct sockaddr *)ap, alen)) {
 		endSocket();
 		error(errBindingFailed,(char *)"Could not bind socket",socket_errno);
 		return;
@@ -2805,7 +2806,7 @@ int DCCPSocket::getTxCCID()
     socklen_t ccidlen;
 
     ccidlen = sizeof(ccid);
-    ret = getsockopt(so, SOL_DCCP, DCCP_SOCKOPT_TX_CCID, &ccid, &ccidlen);
+    ret = getsockopt(so, SOL_DCCP, DCCP_SOCKOPT_TX_CCID, (char *)&ccid, &ccidlen);
     if (ret < 0) {
         cout << "Can not determine get current TX CCID value" << endl;
         return -1;
@@ -2819,7 +2820,7 @@ int DCCPSocket::getRxCCID()
     socklen_t ccidlen;
 
     ccidlen = sizeof(ccid);
-    ret = getsockopt(so, SOL_DCCP, DCCP_SOCKOPT_RX_CCID, &ccid, &ccidlen);
+    ret = getsockopt(so, SOL_DCCP, DCCP_SOCKOPT_RX_CCID, (char *)&ccid, &ccidlen);
     if (ret < 0) {
         cout << "Can not determine get current RX CCID value" << endl;
         return -1;
