@@ -1,4 +1,5 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -492,7 +493,7 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeDummy))
 		PosixThread::sigInstall(SIGPIPE);
 		PosixThread::sigInstall(SIGABRT);
 
-		memset(&act, sizeof(act), 0);
+		memset(&act, 0, sizeof(act));
 		act.sa_handler = (signalexec_t)&ccxx_sig_handler;
 		sigemptyset(&act.sa_mask);
 # ifdef	SA_RESTART
@@ -594,8 +595,6 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeNormal))
 	}
 
 #else
-	int	salign;
-
 	pthread_attr_init(&priv->_attr);
 	pthread_attr_setdetachstate(&priv->_attr, PTHREAD_CREATE_JOINABLE);
 
@@ -607,7 +606,7 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeNormal))
 			stack = PTHREAD_STACK_MIN;
 		else	// align to nearest min boundry
 		{
-			salign = stack / PTHREAD_STACK_MIN;
+			int salign = stack / PTHREAD_STACK_MIN;
 			if(stack % PTHREAD_STACK_MIN)
 				++salign;
 			stack = salign * PTHREAD_STACK_MIN;
@@ -1067,7 +1066,7 @@ static void ccxx_thread_cleanup(void* arg)
 	ThreadImpl::ThreadCleanup( (Thread*)arg );
 		}
 
-	};
+	}
 
 inline void ThreadImpl::ThreadExecHandler(Thread *th)
 {
@@ -1127,7 +1126,7 @@ static void ccxx_exec_handler(Thread *th)
 	ThreadImpl::ThreadExecHandler(th);
 		}
 
-	};
+	}
 #endif // ndef WIN32
 
 #ifdef	CCXX_SIG_THREAD_CANCEL
@@ -1508,7 +1507,7 @@ static void ccxx_sig_handler(int signo)
 	ThreadImpl::PosixThreadSigHandler(signo);
 		}
 
-	};
+	}
 
 PosixThread::PosixThread(int pri, size_t stack):
 	Thread(pri,stack) {
